@@ -21,6 +21,7 @@ import logging
 import base64
 import requests
 from collections.abc import Iterable
+from functools import wraps
 
 from rest3client.ssladapter import SSLAdapter
 from retrying import retry
@@ -41,7 +42,9 @@ class RESTclient():
         'x-api-key',
         'Password',
         'password',
-        'JWT'
+        'JWT',
+        'Token',
+        'token'
     ]
 
     def __init__(self, hostname, **kwargs):
@@ -61,6 +64,8 @@ class RESTclient():
 
         self.bearer_token = kwargs.get('bearer_token')
 
+        self.token = kwargs.get('token')
+
         self.jwt = kwargs.get('jwt')
 
         self.certfile = kwargs.get('certfile')
@@ -90,6 +95,9 @@ class RESTclient():
         if self.bearer_token:
             headers['Authorization'] = f'Bearer {self.bearer_token}'
 
+        if self.token:
+            headers['Authorization'] = self.token
+
         if self.jwt:
             headers['Authorization'] = f'JWT {self.jwt}'
 
@@ -171,6 +179,7 @@ class RESTclient():
     def request_handler(function):
         """ decorator to process arguments and response for request method
         """
+        @wraps(function)
         def _request_handler(self, endpoint, **kwargs):
             """ decorator method to prepare and handle requests and responses
             """
@@ -181,7 +190,6 @@ class RESTclient():
                 return
             response = function(self, endpoint, **arguments)
             return self.get_response(response, **kwargs)
-
         return _request_handler
 
     @request_handler
@@ -214,6 +222,12 @@ class RESTclient():
         """
         return self.session.request('patch', kwargs.pop('address'), **kwargs)
 
+    @request_handler
+    def head(self, endpoint, **kwargs):
+        """ helper method to submit head requests
+        """
+        return self.session.request('head', kwargs.pop('address'), **kwargs)
+
     def get_retry_methods(self):
         """ return list of retry_ methods found in self
         """
